@@ -209,7 +209,7 @@ class KegUi:
     f.GetWidget('when').set_contents(when)
 
   def HandleFlowStatus(self, event):
-    tap_name = event.tap_name
+    tap_name = event.meter_name
     last_status = self._flow_status_by_tap.get(tap_name)
     self._flow_status_by_tap[tap_name] = event
 
@@ -272,10 +272,10 @@ class KrestUpdaterThread(util.KegbotThread):
     while not self._quit:
       self._logger.info('Fetching krest status')
       try:
-        tap_status = self._client.TapStatus()
+        tap_status = self._client.taps()
         self._lcdui.UpdateFromTapStatus(tap_status)
         last_drink = None
-        last_drinks = self._client.AllDrinks()
+        last_drinks = self._client.drinks()
         if last_drinks:
           last_drink = last_drinks[0]
         username = 'unknown'
